// src/index.ts
import { createContext, useContext } from "react";
import {
  useMutation,
  useQuery
} from "@tanstack/react-query";
function useServiceQuery(method, req, options) {
  const reqCtx = useContext(ServiceContext);
  return useQuery({
    ...options,
    queryFn: () => {
      const resp = method(req, {
        ...reqCtx,
        headers: {
          "Content-Type": "application/json",
          ...reqCtx.headers
        }
      });
      if (options?.onError) {
        return resp.catch(options.onError);
      }
      return resp;
    }
  });
}
function useServiceMutation(method, options) {
  const reqCtx = useContext(ServiceContext);
  return useMutation({
    ...options,
    mutationFn: (req) => {
      const resp = method(req, {
        ...reqCtx,
        headers: {
          "Content-Type": "application/json",
          ...reqCtx.headers
        }
      });
      return resp;
    }
  });
}
var ServiceContext = createContext({});
function isErrorResponse(error) {
  return error.code !== void 0;
}
export {
  ServiceContext,
  isErrorResponse,
  useServiceMutation,
  useServiceQuery
};
//# sourceMappingURL=index.js.map